--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- mapinfo.lua
--
local mapinfo = {
	name = "Green Debug Build units",
	description = "",
	author = "",
	version = "",
	mapfile = "maps/green_hills.smf",
	modtype = 3, --// 1 = primary, 0 = hidden, 3 = map
	--depend = {"Map Helper v1"}, --replace = {},
	maphardness = 10000,
	tidalStrength = 0,
	gravity = 150,
	maxMetal = 10,
	extractorRadius = 130,
	autoShowMetal = true,
	smf = {
		minheight = 5,
		maxheight = 100,
		smtFileName0 = "maps/green_hills.smt",
	},
	resources = {
		detailTex = "detailtexbright.bmp",
	},
	atmosphere = {
		minWind = 5,
		maxWind = 22,
		fogStart = -0.3,
		fogEnd = 2.0,
		fogColor = {0.2, 0.2, 0.3},
		sunColor = {1, 0.8, 0.4},
		skyColor = {0.7, 0.7, 0.9},
		skyDir = {1.0, 0.8, 1.0},
		--skyBox       = "",
		cloudDensity = 0.1,
		cloudColor = {1.0, 1.0, 1.0},
	},
	lighting = {
		--// dynsun
		sunStartAngle = 0.0,
		sunOrbitTime = 1440.0,
		sunDir = {1, 0.7, 1},
		--// unit & ground lighting
		groundAmbientColor = {0.6, 0.9, 0.2},
		groundDiffuseColor = {0.9, 0.9, 0.9},
		groundSpecularColor = {0.5, 0.5, 0.5},
		groundShadowDensity = 0.8,
		unitAmbientColor = {0.4, 0.4, 0.4},
		unitDiffuseColor = {1.0, 1.0, 1.0},
		unitSpecularColor = {0.3, 0.3, 0.3},
		unitShadowDensity = 0.8,
		specularExponent = 100.0,
	},
	water = {
		planeColor = {0.0, 0.0, 0.0};
	},
	teams = {},
	terrainTypes = {},
}

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Helper
local function lowerkeys(ta)
	local fix = {}

	for i, v in pairs(ta) do
		if (type(i) == "string") then
			if (i ~= i:lower()) then
				fix[#fix + 1] = i
			end
		end

		if (type(v) == "table") then
			lowerkeys(v)
		end
	end

	for i = 1, #fix do
		local idx = fix[i]
		ta[idx:lower()] = ta[idx]
		ta[idx] = nil
	end
end

lowerkeys(mapinfo)

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Map Options
if (Spring) then
	local function tmerge(t1, t2)
		for i, v in pairs(t2) do
			if (type(v) == "table") then
				t1[i] = t1[i] or {}
				tmerge(t1[i], v)
			else
				t1[i] = v
			end
		end
	end

	-- make code safe in unitsync
	if (not Spring.GetMapOptions) then
		Spring.GetMapOptions = function() return {} end
	end

	function tobool(val)
		local t = type(val)

		if (t == 'nil') then
			return false
		elseif (t == 'boolean') then
			return val
		elseif (t == 'number') then
			return (val ~= 0)
		elseif (t == 'string') then
			return ((val ~= '0') and (val ~= 'false'))
		end

		return false
	end

	getfenv()["mapinfo"] = mapinfo
	local files = VFS.DirList("mapconfig/mapinfo/", "*.lua")
	table.sort(files)

	for i = 1, #files do
		local newcfg = VFS.Include(files[i])

		if newcfg then
			lowerkeys(newcfg)
			tmerge(mapinfo, newcfg)
		end
	end

	getfenv()["mapinfo"] = nil
end

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
return mapinfo
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------